Documentation
¶
Index ¶
- type Canvas
- func (_m *Canvas) ClearScreen(c color.RGBA)
- func (_m *Canvas) CreateNewSprite() models.Sprite
- func (_m *Canvas) Fill(x int, y int, c color.RGBA)
- func (_m *Canvas) GetHeight() int
- func (_m *Canvas) GetUserInput() models.UserInput
- func (_m *Canvas) GetWidth() int
- func (_m *Canvas) SetCartesianPixel(x int, y int, c color.RGBA)
- func (_m *Canvas) SetPixel(x int, y int, c color.RGBA)
- type Sprite
- func (_m *Sprite) Set(visible bool, cartX float64, cartY float64, radianAngle float64)
- func (_m *Sprite) SetPosition(cartX float64, cartY float64)
- func (_m *Sprite) SetRotation(radianAngle float64)
- func (_m *Sprite) SetScale(scale float64)
- func (_m *Sprite) SetSpriteImage(_a0 image.Image)
- func (_m *Sprite) SetSpriteImageArrow()
- func (_m *Sprite) SetSpriteImageTurtle()
- func (_m *Sprite) SetVisible(visible bool)
- type Turtle
- func (_m *Turtle) B(distance float64)
- func (_m *Turtle) Backward(distance float64)
- func (_m *Turtle) Circle(radius float64, angleAmountToDraw float64, steps int)
- func (_m *Turtle) EnableCompassAngleMode(in bool)
- func (_m *Turtle) F(distance float64)
- func (_m *Turtle) Fill(c color.RGBA)
- func (_m *Turtle) Forward(distance float64)
- func (_m *Turtle) GetAngle() float64
- func (_m *Turtle) GetPos() (float64, float64)
- func (_m *Turtle) GoTo(x float64, y float64)
- func (_m *Turtle) L(angle float64)
- func (_m *Turtle) Left(angle float64)
- func (_m *Turtle) Off()
- func (_m *Turtle) On()
- func (_m *Turtle) PD()
- func (_m *Turtle) PU()
- func (_m *Turtle) PaintDot(size float64)
- func (_m *Turtle) PanL(distance float64)
- func (_m *Turtle) PanLeftward(distance float64)
- func (_m *Turtle) PanR(distance float64)
- func (_m *Turtle) PanRightward(distance float64)
- func (_m *Turtle) PenColor(c color.RGBA)
- func (_m *Turtle) PenDown()
- func (_m *Turtle) PenSize(size float64)
- func (_m *Turtle) PenUp()
- func (_m *Turtle) PointToward(x float64, y float64)
- func (_m *Turtle) R(angle float64)
- func (_m *Turtle) Right(angle float64)
- func (_m *Turtle) SetAngle(angle float64)
- func (_m *Turtle) SetDegreesMode()
- func (_m *Turtle) SetRadianMode()
- func (_m *Turtle) SetShapeAsArrow()
- func (_m *Turtle) SetShapeAsImage(in image.Image)
- func (_m *Turtle) SetShapeAsTurtle()
- func (_m *Turtle) SetShapeScale(scale float64)
- func (_m *Turtle) SetSpeed(PixelsPerSecond float64)
- func (_m *Turtle) SetVisible(isVisible bool)
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Canvas ¶
Canvas is an autogenerated mock type for the Canvas type
func NewCanvas ¶
func NewCanvas(t mockConstructorTestingTNewCanvas) *Canvas
NewCanvas creates a new instance of Canvas. It also registers a testing interface on the mock and a cleanup function to assert the mocks expectations.
func (*Canvas) ClearScreen ¶
ClearScreen provides a mock function with given fields: c
func (*Canvas) CreateNewSprite ¶
CreateNewSprite provides a mock function with given fields:
func (*Canvas) GetUserInput ¶
GetUserInput provides a mock function with given fields:
func (*Canvas) SetCartesianPixel ¶
SetCartesianPixel provides a mock function with given fields: x, y, c
type Sprite ¶
Sprite is an autogenerated mock type for the Sprite type
func NewSprite ¶
func NewSprite(t mockConstructorTestingTNewSprite) *Sprite
NewSprite creates a new instance of Sprite. It also registers a testing interface on the mock and a cleanup function to assert the mocks expectations.
func (*Sprite) Set ¶
Set provides a mock function with given fields: visible, cartX, cartY, radianAngle
func (*Sprite) SetPosition ¶
SetPosition provides a mock function with given fields: cartX, cartY
func (*Sprite) SetRotation ¶
SetRotation provides a mock function with given fields: radianAngle
func (*Sprite) SetSpriteImage ¶
SetSpriteImage provides a mock function with given fields: _a0
func (*Sprite) SetSpriteImageArrow ¶
func (_m *Sprite) SetSpriteImageArrow()
SetSpriteImageArrow provides a mock function with given fields:
func (*Sprite) SetSpriteImageTurtle ¶
func (_m *Sprite) SetSpriteImageTurtle()
SetSpriteImageTurtle provides a mock function with given fields:
func (*Sprite) SetVisible ¶
SetVisible provides a mock function with given fields: visible
type Turtle ¶
Turtle is an autogenerated mock type for the Turtle type
func NewTurtle ¶
func NewTurtle(t mockConstructorTestingTNewTurtle) *Turtle
NewTurtle creates a new instance of Turtle. It also registers a testing interface on the mock and a cleanup function to assert the mocks expectations.
func (*Turtle) Circle ¶
Circle provides a mock function with given fields: radius, angleAmountToDraw, steps
func (*Turtle) EnableCompassAngleMode ¶
EnableCompassAngleMode provides a mock function with given fields: in
func (*Turtle) PanLeftward ¶
PanLeftward provides a mock function with given fields: distance
func (*Turtle) PanRightward ¶
PanRightward provides a mock function with given fields: distance
func (*Turtle) PenDown ¶
func (_m *Turtle) PenDown()
PenDown provides a mock function with given fields:
func (*Turtle) PointToward ¶
PointToward provides a mock function with given fields: x, y
func (*Turtle) SetDegreesMode ¶
func (_m *Turtle) SetDegreesMode()
SetDegreesMode provides a mock function with given fields:
func (*Turtle) SetRadianMode ¶
func (_m *Turtle) SetRadianMode()
SetRadianMode provides a mock function with given fields:
func (*Turtle) SetShapeAsArrow ¶
func (_m *Turtle) SetShapeAsArrow()
SetShapeAsArrow provides a mock function with given fields:
func (*Turtle) SetShapeAsImage ¶
SetShapeAsImage provides a mock function with given fields: in
func (*Turtle) SetShapeAsTurtle ¶
func (_m *Turtle) SetShapeAsTurtle()
SetShapeAsTurtle provides a mock function with given fields:
func (*Turtle) SetShapeScale ¶
SetShapeScale provides a mock function with given fields: scale
func (*Turtle) SetVisible ¶
SetVisible provides a mock function with given fields: isVisible